==> vala-0.1.0.tar.bz2: vala-0.1.0/vala/valaconditionalexpression.h <==
/* valaconditionalexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALACONDITIONALEXPRESSION_H__
#define __VALACONDITIONALEXPRESSION_H__
typedef struct _ValaConditionalExpressionPrivate ValaConditionalExpressionPrivate;

#include <glib.h>
#include <glib-object.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_CONDITIONAL_EXPRESSION (vala_conditional_expression_get_type ())
#define VALA_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpression))
#define VALA_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))
#define VALA_IS_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_IS_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_CONDITIONAL_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))


/**
 * Represents a conditional expression in the source code.
 */
struct _ValaConditionalExpression {
	ValaExpression parent;
	ValaConditionalExpressionPrivate * priv;
};
struct _ValaConditionalExpressionClass {
	ValaExpressionClass parent;
};

ValaConditionalExpression* vala_conditional_expression_new (ValaExpression* cond, ValaExpression* true_expr, ValaExpression* false_expr, ValaSourceReference* source);
ValaExpression* vala_conditional_expression_get_condition (ValaConditionalExpression* self);
void vala_conditional_expression_set_condition (ValaConditionalExpression* self, ValaExpression* value);
ValaExpression* vala_conditional_expression_get_true_expression (ValaConditionalExpression* self);
void vala_conditional_expression_set_true_expression (ValaConditionalExpression* self, ValaExpression* value);
ValaExpression* vala_conditional_expression_get_false_expression (ValaConditionalExpression* self);
void vala_conditional_expression_set_false_expression (ValaConditionalExpression* self, ValaExpression* value);
GType vala_conditional_expression_get_type ();

G_END_DECLS

#endif

==> vala-0.3.2.tar.bz2: vala-0.3.2/vala/valaconditionalexpression.h <==
/* valaconditionalexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALACONDITIONALEXPRESSION_H__
#define __VALA_VALACONDITIONALEXPRESSION_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_CONDITIONAL_EXPRESSION (vala_conditional_expression_get_type ())
#define VALA_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpression))
#define VALA_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))
#define VALA_IS_CONDITIONAL_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_IS_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION))
#define VALA_CONDITIONAL_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))

typedef struct _ValaConditionalExpressionPrivate ValaConditionalExpressionPrivate;

/**
 * Represents a conditional expression in the source code.
 */
struct _ValaConditionalExpression {
	ValaExpression parent_instance;
	ValaConditionalExpressionPrivate * priv;
};

struct _ValaConditionalExpressionClass {
	ValaExpressionClass parent_class;
};


ValaConditionalExpression* vala_conditional_expression_new (ValaExpression* cond, ValaExpression* true_expr, ValaExpression* false_expr, ValaSourceReference* source);
ValaExpression* vala_conditional_expression_get_condition (ValaConditionalExpression* self);
void vala_conditional_expression_set_condition (ValaConditionalExpression* self, ValaExpression* value);
ValaExpression* vala_conditional_expression_get_true_expression (ValaConditionalExpression* self);
void vala_conditional_expression_set_true_expression (ValaConditionalExpression* self, ValaExpression* value);
ValaExpression* vala_conditional_expression_get_false_expression (ValaConditionalExpression* self);
void vala_conditional_expression_set_false_expression (ValaConditionalExpression* self, ValaExpression* value);
GType vala_conditional_expression_get_type (void);


G_END_DECLS

#endif
